==> xilinx-language-server-0.0.1.tar.gz: xilinx-language-server-0.0.1/README.md <==
# xilinx-language-server

[![readthedocs](https://shields.io/readthedocs/xilinx-language-server)](https://xilinx-language-server.readthedocs.io)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/Freed-Wu/xilinx-language-server/main.svg)](https://results.pre-commit.ci/latest/github/Freed-Wu/xilinx-language-server/main)
[![github/workflow](https://github.com/Freed-Wu/xilinx-language-server/actions/workflows/main.yml/badge.svg)](https://github.com/Freed-Wu/xilinx-language-server/actions)
[![codecov](https://codecov.io/gh/Freed-Wu/xilinx-language-server/branch/main/graph/badge.svg)](https://codecov.io/gh/Freed-Wu/xilinx-language-server)
[![DeepSource](https://deepsource.io/gh/Freed-Wu/xilinx-language-server.svg/?show_trend=true)](https://deepsource.io/gh/Freed-Wu/xilinx-language-server)

[![github/downloads](https://shields.io/github/downloads/Freed-Wu/xilinx-language-server/total)](https://github.com/Freed-Wu/xilinx-language-server/releases)
[![github/downloads/latest](https://shields.io/github/downloads/Freed-Wu/xilinx-language-server/latest/total)](https://github.com/Freed-Wu/xilinx-language-server/releases/latest)
[![github/issues](https://shields.io/github/issues/Freed-Wu/xilinx-language-server)](https://github.com/Freed-Wu/xilinx-language-server/issues)
[![github/issues-closed](https://shields.io/github/issues-closed/Freed-Wu/xilinx-language-server)](https://github.com/Freed-Wu/xilinx-language-server/issues?q=is%3Aissue+is%3Aclosed)
[![github/issues-pr](https://shields.io/github/issues-pr/Freed-Wu/xilinx-language-server)](https://github.com/Freed-Wu/xilinx-language-server/pulls)
[![github/issues-pr-closed](https://shields.io/github/issues-pr-closed/Freed-Wu/xilinx-language-server)](https://github.com/Freed-Wu/xilinx-language-server/pulls?q=is%3Apr+is%3Aclosed)
[![github/discussions](https://shields.io/github/discussions/Freed-Wu/xilinx-language-server)](https://github.com/Freed-Wu/xilinx-language-server/discussions)
[![github/milestones](https://shields.io/github/milestones/all/Freed-Wu/xilinx-language-server)](https://github.com/Freed-Wu/xilinx-language-server/milestones)
[![github/forks](https://shields.io/github/forks/Freed-Wu/xilinx-language-server)](https://github.com/Freed-Wu/xilinx-language-server/network/members)
[![github/stars](https://shields.io/github/stars/Freed-Wu/xilinx-language-server)](https://github.com/Freed-Wu/xilinx-language-server/stargazers)
[![github/watchers](https://shields.io/github/watchers/Freed-Wu/xilinx-language-server)](https://github.com/Freed-Wu/xilinx-language-server/watchers)
[![github/contributors](https://shields.io/github/contributors/Freed-Wu/xilinx-language-server)](https://github.com/Freed-Wu/xilinx-language-server/graphs/contributors)
[![github/commit-activity](https://shields.io/github/commit-activity/w/Freed-Wu/xilinx-language-server)](https://github.com/Freed-Wu/xilinx-language-server/graphs/commit-activity)
[![github/last-commit](https://shields.io/github/last-commit/Freed-Wu/xilinx-language-server)](https://github.com/Freed-Wu/xilinx-language-server/commits)
[![github/release-date](https://shields.io/github/release-date/Freed-Wu/xilinx-language-server)](https://github.com/Freed-Wu/xilinx-language-server/releases/latest)

[![github/license](https://shields.io/github/license/Freed-Wu/xilinx-language-server)](https://github.com/Freed-Wu/xilinx-language-server/blob/main/LICENSE)
[![github/languages](https://shields.io/github/languages/count/Freed-Wu/xilinx-language-server)](https://github.com/Freed-Wu/xilinx-language-server)
[![github/languages/top](https://shields.io/github/languages/top/Freed-Wu/xilinx-language-server)](https://github.com/Freed-Wu/xilinx-language-server)
[![github/directory-file-count](https://shields.io/github/directory-file-count/Freed-Wu/xilinx-language-server)](https://github.com/Freed-Wu/xilinx-language-server)
[![github/code-size](https://shields.io/github/languages/code-size/Freed-Wu/xilinx-language-server)](https://github.com/Freed-Wu/xilinx-language-server)
[![github/repo-size](https://shields.io/github/repo-size/Freed-Wu/xilinx-language-server)](https://github.com/Freed-Wu/xilinx-language-server)
[![github/v](https://shields.io/github/v/release/Freed-Wu/xilinx-language-server)](https://github.com/Freed-Wu/xilinx-language-server)

[![pypi/status](https://shields.io/pypi/status/xilinx-language-server)](https://pypi.org/project/xilinx-language-server/#description)
[![pypi/v](https://shields.io/pypi/v/xilinx-language-server)](https://pypi.org/project/xilinx-language-server/#history)
[![pypi/downloads](https://shields.io/pypi/dd/xilinx-language-server)](https://pypi.org/project/xilinx-language-server/#files)
[![pypi/format](https://shields.io/pypi/format/xilinx-language-server)](https://pypi.org/project/xilinx-language-server/#files)
[![pypi/implementation](https://shields.io/pypi/implementation/xilinx-language-server)](https://pypi.org/project/xilinx-language-server/#files)
[![pypi/pyversions](https://shields.io/pypi/pyversions/xilinx-language-server)](https://pypi.org/project/xilinx-language-server/#files)

Language server for xilinx:

- [vivado](https://www.xilinx.com/support/download/index.html/content/xilinx/en/downloadNav/vivado-design-tools.html)

- [vitis](https://www.xilinx.com/support/download/index.html/content/xilinx/en/downloadNav/vitis.html)

- [x] document hover

- [x] completion

![document hover](https://github.com/Freed-Wu/pkgbuild-language-server/assets/32936898/2b4c4683-5b6c-458a-92fc-d98c041277a9)

![completion](https://github.com/Freed-Wu/pkgbuild-language-server/assets/32936898/7a0b15d5-9070-446d-b1b9-a4cdcc79f522)

Read
[![readthedocs](https://shields.io/readthedocs/xilinx-language-server)](https://xilinx-language-server.readthedocs.io)
to know more.

## Documents

- [vivado-system-level-design-entry](https://docs.xilinx.com/r/en-US/ug895-vivado-system-level-design-entry)
- [vivado-tcl-commands](https://docs.xilinx.com/r/en-US/ug835-vivado-tcl-commands)
- [vitis-embedded](https://docs.xilinx.com/r/en-US/ug1400-vitis-embedded)

## Related Projects

- [xilinx.vim](https://github.com/Freed-Wu/xilinx.vim)

==> xilinx-language-server-0.0.4.tar.gz: xilinx-language-server-0.0.4/README.md <==
# xilinx-language-server

[![readthedocs](https://shields.io/readthedocs/xilinx-language-server)](https://xilinx-language-server.readthedocs.io)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/Freed-Wu/xilinx-language-server/main.svg)](https://results.pre-commit.ci/latest/github/Freed-Wu/xilinx-language-server/main)
[![github/workflow](https://github.com/Freed-Wu/xilinx-language-server/actions/workflows/main.yml/badge.svg)](https://github.com/Freed-Wu/xilinx-language-server/actions)
[![codecov](https://codecov.io/gh/Freed-Wu/xilinx-language-server/branch/main/graph/badge.svg)](https://codecov.io/gh/Freed-Wu/xilinx-language-server)
[![DeepSource](https://deepsource.io/gh/Freed-Wu/xilinx-language-server.svg/?show_trend=true)](https://deepsource.io/gh/Freed-Wu/xilinx-language-server)

[![github/downloads](https://shields.io/github/downloads/Freed-Wu/xilinx-language-server/total)](https://github.com/Freed-Wu/xilinx-language-server/releases)
[![github/downloads/latest](https://shields.io/github/downloads/Freed-Wu/xilinx-language-server/latest/total)](https://github.com/Freed-Wu/xilinx-language-server/releases/latest)
[![github/issues](https://shields.io/github/issues/Freed-Wu/xilinx-language-server)](https://github.com/Freed-Wu/xilinx-language-server/issues)
[![github/issues-closed](https://shields.io/github/issues-closed/Freed-Wu/xilinx-language-server)](https://github.com/Freed-Wu/xilinx-language-server/issues?q=is%3Aissue+is%3Aclosed)
[![github/issues-pr](https://shields.io/github/issues-pr/Freed-Wu/xilinx-language-server)](https://github.com/Freed-Wu/xilinx-language-server/pulls)
[![github/issues-pr-closed](https://shields.io/github/issues-pr-closed/Freed-Wu/xilinx-language-server)](https://github.com/Freed-Wu/xilinx-language-server/pulls?q=is%3Apr+is%3Aclosed)
[![github/discussions](https://shields.io/github/discussions/Freed-Wu/xilinx-language-server)](https://github.com/Freed-Wu/xilinx-language-server/discussions)
[![github/milestones](https://shields.io/github/milestones/all/Freed-Wu/xilinx-language-server)](https://github.com/Freed-Wu/xilinx-language-server/milestones)
[![github/forks](https://shields.io/github/forks/Freed-Wu/xilinx-language-server)](https://github.com/Freed-Wu/xilinx-language-server/network/members)
[![github/stars](https://shields.io/github/stars/Freed-Wu/xilinx-language-server)](https://github.com/Freed-Wu/xilinx-language-server/stargazers)
[![github/watchers](https://shields.io/github/watchers/Freed-Wu/xilinx-language-server)](https://github.com/Freed-Wu/xilinx-language-server/watchers)
[![github/contributors](https://shields.io/github/contributors/Freed-Wu/xilinx-language-server)](https://github.com/Freed-Wu/xilinx-language-server/graphs/contributors)
[![github/commit-activity](https://shields.io/github/commit-activity/w/Freed-Wu/xilinx-language-server)](https://github.com/Freed-Wu/xilinx-language-server/graphs/commit-activity)
[![github/last-commit](https://shields.io/github/last-commit/Freed-Wu/xilinx-language-server)](https://github.com/Freed-Wu/xilinx-language-server/commits)
[![github/release-date](https://shields.io/github/release-date/Freed-Wu/xilinx-language-server)](https://github.com/Freed-Wu/xilinx-language-server/releases/latest)

[![github/license](https://shields.io/github/license/Freed-Wu/xilinx-language-server)](https://github.com/Freed-Wu/xilinx-language-server/blob/main/LICENSE)
[![github/languages](https://shields.io/github/languages/count/Freed-Wu/xilinx-language-server)](https://github.com/Freed-Wu/xilinx-language-server)
[![github/languages/top](https://shields.io/github/languages/top/Freed-Wu/xilinx-language-server)](https://github.com/Freed-Wu/xilinx-language-server)
[![github/directory-file-count](https://shields.io/github/directory-file-count/Freed-Wu/xilinx-language-server)](https://github.com/Freed-Wu/xilinx-language-server)
[![github/code-size](https://shields.io/github/languages/code-size/Freed-Wu/xilinx-language-server)](https://github.com/Freed-Wu/xilinx-language-server)
[![github/repo-size](https://shields.io/github/repo-size/Freed-Wu/xilinx-language-server)](https://github.com/Freed-Wu/xilinx-language-server)
[![github/v](https://shields.io/github/v/release/Freed-Wu/xilinx-language-server)](https://github.com/Freed-Wu/xilinx-language-server)

[![pypi/status](https://shields.io/pypi/status/xilinx-language-server)](https://pypi.org/project/xilinx-language-server/#description)
[![pypi/v](https://shields.io/pypi/v/xilinx-language-server)](https://pypi.org/project/xilinx-language-server/#history)
[![pypi/downloads](https://shields.io/pypi/dd/xilinx-language-server)](https://pypi.org/project/xilinx-language-server/#files)
[![pypi/format](https://shields.io/pypi/format/xilinx-language-server)](https://pypi.org/project/xilinx-language-server/#files)
[![pypi/implementation](https://shields.io/pypi/implementation/xilinx-language-server)](https://pypi.org/project/xilinx-language-server/#files)
[![pypi/pyversions](https://shields.io/pypi/pyversions/xilinx-language-server)](https://pypi.org/project/xilinx-language-server/#files)

Language server for xilinx:

- [vivado](https://www.xilinx.com/support/download/index.html/content/xilinx/en/downloadNav/vivado-design-tools.html)
- [vitis](https://www.xilinx.com/support/download/index.html/content/xilinx/en/downloadNav/vitis.html)
- [x] document hover
- [x] completion

![document hover](https://github.com/Freed-Wu/xilinx-language-server/assets/32936898/ad13e891-0d73-457c-9899-3a2e2f86cbe2)

![completion](https://github.com/Freed-Wu/xilinx-language-server/assets/32936898/2111f6fe-d42a-4ef7-b529-688f3a139959)

Read
[![readthedocs](https://shields.io/readthedocs/xilinx-language-server)](https://xilinx-language-server.readthedocs.io)
to know more.

## Documents

- [vivado-system-level-design-entry](https://docs.xilinx.com/r/en-US/ug895-vivado-system-level-design-entry)
- [vivado-tcl-commands](https://docs.xilinx.com/r/en-US/ug835-vivado-tcl-commands)
- [vitis-embedded](https://docs.xilinx.com/r/en-US/ug1400-vitis-embedded)

## Update

Install `vivado` and `vitis`, then

- Run `scripts/vivado.tcl` to update `src/xilinx_language_server/assets/json/vivado.json`
- Run `scripts/xsct.tcl` to update `src/xilinx_language_server/assets/json/xsct.json`

## Related Projects

- [xilinx.vim](https://github.com/Freed-Wu/xilinx.vim): vim filetype plugin
  for xilinx
